! +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
!.IDENTIFICATION: ccdtestb.prg
!.PURPOSE:        Procedure to determine the ccd bias characteristics
!.AUTHORS:        Rein H. Warmels, Thomas Augusteijn
!.USE:            @s ccdtestb p1 p2 p3 p4 p5 p6 p7 p8 
!.                where p1 = test to be done B1 to B5 or all,
!.                      p2 = input catalogue containing the ccd bias frames
!.                      p3 = output identifier [bias]
!.                      p4 = method for computing the combined bias
!.                      p5 = row range to be averaged
!.                      p6 = column range to be averaged
!.                      p7 = area
!.                      p8 = radius of smoothing box for median filtering,
!.                           decimation factor for image size reduction
!.Algorithm:      The following tests are done:
!                 Test B1: Creation of the combine bias frame. The combining
!                          method is taken from P3.
!                          The result is load onto the display and a hardcopy
!                          is generated in file {p3}_aver.ps
!                 Test B2: From the combined bias frame row and columns are 
!                          averaged and plotted. The result plot are stored
!                          in the files {p3}_avcol.ps and {p2}_avrow.ps.
!                 Test B3: Find the hot pixels.
!                          The combined bias frame is median filtered and 
!                          subtracted from the original. A plot is generated 
!                          showing the position of the hot pixels and the 
!                          affected columns (file {p3}_hotpix.ps). A MIDAS
!                          table ({p3}_hotpix.tbl).
!                 Test B4: Inspection of single frame: the first and the last 
!                          one in the catalogue. For the first one a histogram
!                          of the pixel values is made, ignoring the hot pixels
!                          The plot file can be found in {p3}_hist.ps. For the
!                          last frame in the catalogue is first corrected for 
!                          hot pixels and then rebin 
!                 Test B5: Determination of the bias level and standard 
!                          deviation. For each input frame in the catalogue 
!                          determine the  mean bias and standard deviation 
!                          after hot pixel correction, box averaging and 
!                          median filtering. The overall mean bias level and 
!                          mean sigma is computed."
!.VERSION:  
! 940620	creation RHW
! 950115	Inclusion of the subtest 
! 960429	new defaults for windows. PS
! 970510	more statistics of Bias images PS
! 100407	last modif
! +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
! 
DEFINE/PARAMETER P1  ALL          C  "Enter test to be executed;"
DEFINE/PARAMETER P2  ?            C  "Enter input catalogue:"
DEFINE/PARAMETER P3  BIAS         C  "Enter combined output frame:"
DEFINE/PARAMETER P4  median       C  "Combining method:"
DEFINE/PARAMETER P5  @2,>         C  "Enter row numbers for averaging:" 
DEFINE/PARAMETER P6  @15,>        C  "Enter column numbers for averaging:" 
DEFINE/PARAMETER P7  [@15,@2:>,>] C  "Enter area:"
DEFINE/PARAMETER P8  5,10         N  "Radius med. filtering, and dec. factor:"
!
WRITE/KEY    INPUTI/I/1/2     {P8}
WRITE/KEY    RADIUS/I/1/1     {INPUTI(1)}
write/key biasmean/r/1/1 0.0
write/key biassigm/r/1/1 0.0
write/key hot_pix/i/1/1 0
write/key hot_tabl/c/1/40  " " 
DEFINE/LOCAL NBOX/I/1/1       {INPUTI(2)}
DEFINE/LOCAL BSSTA/R/1/1      0.0
DEFINE/LOCAL BSEND/R/1/1      0.0
DEFINE/LOCAL BSSTE/R/1/1      0.0
DEFINE/LOCAL XSTA/R/1/1       0.0
DEFINE/LOCAL XEND/R/1/1       0.0
DEFINE/LOCAL YSTA/R/1/1       0.0
DEFINE/LOCAL YEND/R/1/1       0.0
DEFINE/LOCAL REBIN/C/1/3      " "
DEFINE/LOCAL XLAB/R/1/1       0.0
DEFINE/LOCAL YLAB/R/1/1       0.0
DEFINE/LOCAL SCALE/R/1/1       0.0
DEFINE/LOCAL XSCALE/I/1/1      0
DEFINE/LOCAL YSCALE/I/1/1      0
log/tof
WRITE/OUT "     PROCEDURE TO DETERMINE THE CCD BIAS CHARACTERISTICS"
write/out "     ==================================================="
write/out " "
write/out " "
write/out "  command line: "
write/out " @@ ccdtestb {p1} {p2} {p3}"
write/out "    {p4} {p5} {p6} {p7} {p8}"
write/out " "

! *** check if the catalogue exists
IF M$EXIST("{P2}") .EQ. 0 THEN
   WRITE/OUT "FATAL <CCDTESTB>: Catalogue {P2} not existing"
   errsum = errsum + 1
   RETURN
ENDIF
!
read/icat {p2}
create/display
clear/chan over
load/lut heat
create/graph 
set/graph default
!
define/local catal/i/1/1 0
define/local nfrm/i/1/1 0
! 
LOOP1:
   store/frame in_a {p2} 1 CONT1
   nfrm = nfrm + 1
   if nfrm .eq. 1 then
       define/local frm1/c/1/60 {in_a}
   endif
   goto LOOP1
! 
CONT1:
define/local frmn/c/1/60 {in_a}
!
BRANCH P1(1:2) B1,B2,B3,B4,B5 TESTB1,TESTB2,TESTB3,TESTB4,TESTB5
!
TESTB1:
write/out " "
WRITE/OUT "Test B1: Creating combined master bias frame"
write/out "----------------------------------------------------------------"
write/out "All frames in the input catalogue are combined using the"
write/out "<{P4}> method. The output frame will be {P3}_cbias.bdf.
write/out " "
!
! *** first set all the keywords for the combining
IF M$EXIST("{P3}_cbias.bdf") .EQ. 0 THEN
   define/local sav_met/c/1/20   "{bs_met}"       ! save the combining method
   write/key    bs_met/c/1/20    "{p4}"           ! store new method
   define/local sav_del/c/1/3    "{bs_del}"       ! save the combining method
   write/key    bs_del/c/1/3     "NO"             ! store new method
   define/local sav_typ/c/1/60   "{bs_typ}"       ! save the exposure type
   write/key    bs_typ/c/1/60    "?"              ! store new method
   delete/ima {p3} no
   combine/ccd  bs {p2} {p3}_cbias
   write/key    bs_met/c/1/20    "{sav_met}"      ! restore method
   write/key    bs_del/c/1/3     "{sav_del}"      ! restore deletion option
   write/key    bs_typ/c/1/60    "{sav_typ}"      ! restore exposure type
else 
  WRITE/OUT "Combined bias frame {P3}_cbias.bdf exists; no new one created"
ENDIF
write/keyw SC_BSFRM/c/1/60 {p3}_cbias
!
statistics/imag {p3}_cbias ? ? ? FN              ! calculate statistics
write/keyw rcorr -
238,245,241.509,0.941194,-0.155556,3.20796,9.66035e+06,241.954,238.014
@@ kcompare ccdb010:rcorr outputr 1,2 0.1 3,3 0.001 4,6 0.00005 
@@ kcompare ccdb011:rcorr outputr 8,9 0.005 
write/keyw icorr/i/1/5  40000,55,24,124,4 
@@ kcompare ccdb012:icorr outputi 1,5
! 
bssta = OUTPUTR(3) - 5.0 * OUTPUTR(4)   ! eliminate hotpixel contrib.
bsend = OUTPUTR(3) + 5.0 * OUTPUTR(4)
statistics/imag {p3}_cbias ? ? {bssta},{bsend} FN
bssta = OUTPUTR(3) - 1.5 * OUTPUTR(4)
bsend = OUTPUTR(3) + 1.5 * OUTPUTR(4)
cuts {p3}_cbias {bssta},{bsend}

scale = {{p3}_cbias,NPIX(1)}. / ididev(2)
if scale .lt. 1.0 then
   xscale = 1.0 / scale
  else
   xscale = -scale - 1
endif

scale = {{p3}_cbias,NPIX(2)}. / ididev(3)
if scale .lt. 1.0 then
   yscale = 1.0 / scale
else
   yscale = -scale - 1
endif

load/image {p3}_cbias scale={xscale},{yscale}
set/midas output=no
copy/display p5=noprint
-copy screen{mid$sess(11:12)}.ps {p3}_cbias.ps
set/midas output=yes

IF P1(1:3) .NE. "ALL" RETURN
!
!
TESTB2:
write/out "Test B2: Inspection of combined bias frame:"
write/out "----------------------------------------------------------------"
!
write/out "Averaging rows {p5} of the stacked bias frame;"
write/out "Output frame will be {p3}_avrow.bdf;"
average/row {p3}_avrow = {p3}_cbias {p5}                    ! average rows
statistics/imag {p3}_avrow ? ? ? GN                      ! calculate statistics
write/keyw rcorr -
241.171,241.688,241.508,0.0768577,-0.381781,3.24802,48301.7,241.508,241.172 
@@ kcompare ccdb020:rcorr outputr 1,3 0.005 4,5 0.0005 7,7 0.1 
@@ kcompare ccdb022:rcorr outputr 8,9 0.005 
! compiler stuff...
compute/image &d = {p3}_avrow - Std_norm_avrow
find/minmax &d
write/keyw rcorr 0.0,0.0
@@ kcompare ccdb024:rcorr outputr 1,2 0.0001
! 
ysta = OUTPUTR(8) - 4                                 ! get relevant y range
yend = OUTPUTR(8) + 4
set/gra yaxis={ysta},{yend} pmode=1                   ! set the y axis
plot/row {p3}_avrow @1 ?  -140,-40,25,75              ! plot the row
set/graph clear=off
!
! *** Plot the bias level averaged over columns
write/out " "
write/out "Averaging columns {p6} of the stacked bias frame;"
write/out "Output frame will be {p3}_avcol.bdf"
average/column {p3}_avcol = {p3}_cbias {p6}           ! average columns
statistics/imag {p3}_avcol ? ? ? GN                      ! calculate statistics
write/keyw rcorr -
 241.269,241.688,241.511,0.0743431,-0.256732,1.27054,48302.3,241.516,241.27  
@@ kcompare ccdb026:rcorr outputr 1,3 0.005 4,5 0.0005 7,7 0.1
@@ kcompare ccdb027:rcorr outputr 8,9 0.005
! compiler stuff...
compute/image &d = {p3}_avcol - Std_norm_avcol
find/minmax &d
write/keyw rcorr 0.0,0.0
@@ kcompare ccdb029:rcorr outputr 1,2 0.0001
! 
ysta = OUTPUTR(8) - 4                                 ! get relevant y range
yend = OUTPUTR(8) + 4
set/graph yaxis={ysta},{yend} pmode=1                   ! set the y axis
plot/row {p3}_avcol @1 ? -140,-40,25,15               ! plot column
set/graph
copy/graph postscript
-copy postscript.ps {p3}_aver.ps
! write/out " "
! write/out "Plot file is in {p3}_aver.ps"
! 
write/out " "
write/out "End of test B2"
write/out " "
IF P1(1:3) .NE. "ALL" RETURN
!
!
TESTB3:
write/out "Test B3: Finding the hot pixels"
write/out "------------------------------------------------------------------"
write/out "Generate a table with hot pixels in area {p7}"
write/out "by subtracting the median smoothed stacked bias from the "
write/out "unsmoothed one and doing statistics of the result frame."
write/out "A plot and a MIDAS table with the hot pixels area is produced."
write/out "If hot pixels are found, a new average row in range {p5}"
write/out "and column in range {p6} are produced to remove the effect"
write/out "of possible hot columns. "
write/out " "
!
IF M$EXIST("{P3}_hotpix.bdf") .EQ. 0  THEN
   write/out "     WARNING: Median filtering will take a while; don't panic."
   write/out " "
   set/format i1
   filter/median {p3}_cbias &s {RADIUS},{RADIUS},0.0 ? {p7}
   compute/image {p3}_hotpix = {p3}_cbias - &s
else
   WRITE/OUT "Hot pixel frame {p3}_hotpix.bdf exists;"
   write/out "no new one created"
   write/out " "
endif
!
write/desc {p3}_hotpix IDENT/C/1/40 "{DETEC} - Hot pixels"
statistics/ima {p3}_hotpix {p7} ? ? FN
write/keyw rcorr -
-4,4,-0.104663,1.02876,-0.0812355,3.17402,-3874,-0.0340525,-3.98431 
@@ kcompare ccdb030:rcorr outputr 1,2 0.1 3,6 0.0005 7,7 0.1
@@ kcompare ccdb032:rcorr outputr 8,9 0.00005
!
bssta = OUTPUTR(3) - 5 * OUTPUTR(4)
bsend = OUTPUTR(3) + 5 * OUTPUTR(4)
statistics/ima {p3}_hotpix {p7} ? {bssta},{bsend} FN
!
bssta = OUTPUTR(3) + 5 * OUTPUTR(4)
bsend = OUTPUTR(3) + 9 * OUTPUTR(4)
set/graph frame=square xaxis= yaxis= pmode=1
extr/ima &s = {p3}_hotpix{p7}
plot/cont &s ? ? {bssta} NEG 
bssta = -999999
find/pixel &s {bssta},{bsend} out A dummtab 50000
IF OUTPUTI(1) .EQ. 0 THEN
   set/format f8.2
   WRITE/OUT "*** INFO: No pixels found outside range {bssta}, {bsend}"
   WRITE/OUT "          No hot pixel image and table produced"
   write/out " "
   set/format i1 e15.5
   IF P1 .EQ. "ALL" THEN 
      GOTO TESTB4
   ELSE 
      RETURN
   ENDIF
ENDIF
! 
! this section should NOT be reached with the data in our specific test...
! 
WRITE/OUT "FATAL we should never come here...
errsum = errsum + 1
RETURN

! we just keep the original code 
! ================================================================================
! changes for Midas97:   Table column names have changed!
if mid$sess(16:17) .gt. "95" then
  name/colu dummtab :x_pix :x
  name/colu dummtab :y_pix :y
else
  name/colu dummtab :x_coord :x
  name/colu dummtab :y_coord :y
endif
sort/tab dummtab :x,:y  
write/keyw in_a/c/1/60  dummtab
write/keyw out_a/c/1/60 {p3}_hotpix
set/format i1 f10.0
write/out " "
run STD_EXE:ccdhotpix
set/format
!
hot_tabl = "{p3}_hotpix"
set/midas output=no
select/tabl {p3}_hotpix :VALUE.GT.0.0
read/tabl {p3}_hotpix
overpl/tabl {p3}_hotpix :x :y 5
show/tab {p3}_hotpix
hot_pix = outputi(2)
copy/gra postscript
-copy postscript.ps {p3}_hotpix.ps
set/midas output=yes
write/out " "
write/out "The contour plot with hot pixels inside the area "
write/out "{p7} is stored in the file "
write/out "{p3}_hotpix.ps. The MIDAS table containing "
write/out "the hot pixels/cols is in {p3}_hotpix.tbl"
write/out " "
write/out "There were {hot_pix} hot pixels/columns found "
write/out " "

write/out "Now we do again the row and column averages with a clean image:"
write/out " "
write/out "Averaging rows {p5} of the stacked bias frame;"
write/out "Output frame will be {p3}_avrow_clean.bdf;"
set/midas output=no
modify/colu {p3}_cbias,{p3}_hotpix &a V                   ! modify the hot pixels
average/row {p3}_avrow_clean = &a {p5}                 ! average rows
statist/imag {p3}_avrow_clean ? ? ? GN                 ! calculate statistics
ysta = OUTPUTR(8) - 4                                 ! get relevant y range
yend = OUTPUTR(8) + 4
set/gra yaxis={ysta},{yend} pmode=1                   ! set the y axis
plot/row {p3}_avrow_clean @1 ?  -140,-40,25,75         ! plot the row
set/grap clear=off

! *** Plot the bias level averaged over columns
set/midas output=yes
write/out " "
write/out "Averaging columns {p6} of the stacked bias frame"
write/out "Output frame will be {p3}_avcol_clean.bdf"
set/midas output=no
average/col {p3}_avcol_clean = &a {p6}                ! average columns
statist/imag {p3}_avcol_clean ? ? ? GN                ! calculate statistics
ysta = OUTPUTR(8) - 4                                 ! get relevant y range
yend = OUTPUTR(8) + 4
set/gra yaxis={ysta},{yend}  pmode=1                  ! set the y axis
plot/row {p3}_avcol_clean @1 ? -140,-40,25,15         ! plot column
set/gra

copy/gra postscript
-copy postscript.ps {p3}_aver_clean.ps
set/midas output=yes
write/out " "
write/out "Plot file is in {p3}_aver_clean.ps"
write/out " "
write/out "End of test B3"
write/out " "
set/gra
delete/imag &a no
delete/imag &s NO
delete/tabl dummtab NO
IF P1(1:3) .NE. "ALL" RETURN
! ================================================================================

!
TESTB4:
set/format i1
write/out "Test B4: Inspection of single bias frames:"
write/out "------------------------------------------------------------------"
write/out "A histogram of the pixel intensities of frame {frm1}"
write/out "over the area {p7} is computed, ignoring the hot pixels"
write/out "and cosmics, and stored in the table {p3}_hotpix.tbl."
write/out "The frame {frmn} is cleaned from hot pixels and cosmics. "
write/out "Hereafter the clean frame is rebinned using a median filter "
write/out "over {RADIUS}x{RADIUS} pixels; output in {p3}_rebin.ps"
!write/out "The rows {p5} of the single bias frame will be averaged"
!write/out "and the FFT will be computed. Output frames are {P3}_real.bdf"
!write/out "and {P3}_imag.bdf;"
write/out " "

! *** Plot a histogram distribution of a bias frame 
statistics/image {frm1} {p7} ? ? FN
write/keyw rcorr -
 233,248,241.399,1.73238,-0.10165,2.99078,8.93513e+06,240.938,233.029  
@@ kcompare ccdb040:rcorr outputr 1,2 0.1 3,3 0.001 4,6 0.0005 
@@ kcompare ccdb042:rcorr outputr 8,9 0.001
xsta = OUTPUTR(3) - 30.
xend = OUTPUTR(3) + 30.
statistics/image {frm1} {p7} 1 {xsta},{xend} FN
write/keyw rcorr -
233,248,241.399,1.73238,-0.10165,2.99078,8.93513e+06,241.351,233.899
@@ kcompare ccdb044:rcorr outputr 1,2 0.1 3,3 0.001 4,6 0.0005 
@@ kcompare ccdb045:rcorr outputr 8,9 0.001
set/graph xaxis={xsta},{xend} yaxis= frame=rect pmode=1
plot/hist {frm1}
copy/graph postscript
-copy postscript.ps {p3}_hist.ps
! write/out " "
! write/out "Plot of the histogram is in file {p3}_hist.ps"
set/graph clear=on
!
! *** Now produce clean and rebined bias frame
!
IF hot_pix .NE. 0 THEN
 modify/column {frmn},{p3}_hotpix &a V                   ! modify the hot pixels
ELSE
 comp/ima &a = {frmn}
ENDIF
!
extr/ima middumma = middumma{p7}
write/key rebin/c/1/3 "med"
in_a  = "middumma"
out_a = "{p3}_rebin"
run STD_EXE:ccdrebin

! restore CCD coordinates
xsta = {&a,start(1)} + {nbox}/2
ysta = {&a,start(2)} + {nbox}/2
write/desc {p3}_rebin start/d/1/2 {xsta},{ysta}
write/desc {p3}_rebin step/d/1/2 {nbox},{nbox}

set/midas output=no
statistics/ima {p3}_rebin
set/midas output=yes
write/keyw rcorr -
241,242,241.698,0.443194,-0.861246,1.82616,82661,241.993,241.002
@@ kcompare ccdb050:rcorr outputr 1,2 0.1 3,6 0.001 7,7 0.1
@@ kcompare ccdb052:rcorr outputr 8,9 0.01
xsta = OUTPUTR(3) - 1.0*OUTPUTR(4)
xend = OUTPUTR(3) + 1.0*OUTPUTR(4)
cuts/imag {p3}_rebin {xsta},{xend}
scale = {{p3}_rebin,NPIX(1)}. / ididev(2)
if scale .lt. 1.0 then
   xscale = 1.0 / scale
  else
   xscale = -scale - 1
 endif
scale = {{p3}_rebin,NPIX(2)}. / ididev(3)
if scale .lt. 1.0 then
   yscale = 1.0 / scale
  else
   yscale = -scale - 1
 endif
load/imag {p3}_rebin scale={xscale},{yscale}
copy/display p5=noprint >Null
-copy screen{mid$sess(11:12)}.ps {p3}_rebin.ps
! write/out "Cleaned and rebinned bias frame is in file {p3}_rebin.ps"
! 
delete/imag &a no
delete/imag &b no
IF P1(1:3) .NE. "ALL" RETURN
!
!
TESTB5:
write/out "Test B5: Determination of the bias level and standard deviation"
write/out "------------------------------------------------------------------"
write/out "For each input frame in the catalogue determine the mean"
write/out "BIAS and standard deviation AFTER hot pixel correction,"
write/out "Box averaging and median filtering, and using area {P7}." 
write/out "Finally, the overall mean bias level and sigma are computed."
write/out
define/local mean/r/1/1 0.0
define/local sigm/r/1/1 0.0
define/local meandif/r/1/1 0.0
define/local sigmdif/r/1/1 0.0
define/local meanstd/r/1/1 0.0
define/local sigmstd/r/1/1 0.0
define/local frame/c/1/60 " "
write/key    catal/i/1/1 0
write/key    rebin/c/1/3 "mea"
define/local ifrm/i/1/1 0
create/table   {p3}_mean 3 10 null
create/column   {p3}_mean :NAME  "   " A20  C*20
create/column   {p3}_mean :MEAN  "ADU" F9.4 R*4
create/column   {p3}_mean :SIGMA "ADU" F9.4 R*4
! 
LOOP2:
   store/frame in_a {p2} 1 FINISH
   ifrm  = ifrm + 1
   frame = in_a
   IF OUTPUTI(1) .EQ. 0 THEN
      modify/colu {in_a},{p3}_hotpix middumma V        ! modify the hot pixels
   ELSE
      comp/ima middumma = {frame}
   ENDIF
   extr/ima middumma = middumma{p7}
   in_a  = "middumma"
   out_a = "bs_mean"
   out_b = "bs_sigm"
   run STD_EXE:ccdrebin
   filter/median {OUT_A} &a {RADIUS},{RADIUS},0.0  >Null
   filter/median {OUT_B} &b {RADIUS},{RADIUS},0.0  >Null
   statistics/ima &a ? ? ? NN
   mean  = outputr(3)
   statistics/ima &b ? ? ? NN
   sigm = outputr(3)
   {p3}_mean,:NAME,@{ifrm}  = "{frame}"
   {p3}_mean,:MEAN,@{ifrm}  =  mean
   {p3}_mean,:SIGMA,@{ifrm} =  sigm
   set/format t6.2
   write/out "     Statistics of {frame}:  mean =  {mean};  noise ={sigm}"
   goto LOOP2
! 
FINISH:
ifrm = ifrm + 1
sele/table {p3}_mean seq.lt.{ifrm}
{p3}_mean,:NAME,@{ifrm}  = "all_average"
statistics/table {p3}_mean :MEAN
write/keyw rcorr 241.398,241.596,241.458,0.0813058 
@@ kcompare ccdb060:rcorr outputr 1,4 0.005 
! 
biasmean = outputr(3)
{p3}_mean,:MEAN,@{ifrm}  =  biasmean
meandif = outputr(2) - outputr(1)
meanstd = outputr(4)
statistics/table {p3}_mean :SIGMA
write/keyw rcorr 1.69813,1.7177,1.70873,0.00742274  
@@ kcompare ccdb063:rcorr outputr 1,4 0.0002 
! 
biassigm = outputr(3)
{p3}_mean,:SIGMA,@{ifrm} =  biassigm
sigmdif = outputr(2) - outputr(1)
sigmstd = outputr(4)
ifrm = ifrm - 1
! 
delete/imag {OUT_A} no
delete/imag {OUT_B} no
delete/imag &a no
delete/imag &s no

set/format i1 t6.2
write/out " "
write/out -
       "     Average of  {ifrm} bias frames:  mean =  {biasmean};  noise ={biassigm}"
write/out " "
write/out -
       "     mean/noise diff.(max-min):  mean =  {meandif};  noise ={sigmdif}"  
write/out -
       "     mean/noise std. deviation:  mean =  {meanstd};  noise ={sigmstd}"  
write/out " "
write/out "The MIDAS table with results is in file {p3}_mean.tbl"
write/out " "
write/out "End of test B5"
write/out " "
set/format
!
! cleanup 
delete/ima bs_sigm.bdf NO
delete/ima bs_mean.bdf NO
delete/ima postscript.ps NO
delete/ima screen*.ps NO
delete/ima screen*.ima NO
delete/ima graph*.plt NO
delete/ima middumma.bdf NO
delete/table dummtab.tbl NO
set/graph default





